function [y]=rbfSVMtest(h,VS,ay,g)
%  h=histogram representation [1x1104]
%  VS = support vector in histogram representation [52x1104]
%  ay = coefficients of support [52x1]
%   g = gaussian width  [1x1]

 n=size(VS,1);
 y=0;
 for i=1:n
  D=h-VS(i,:);
  D2=sum(D.^2);
  y=y+ay(i)*exp(-0.5*D2/g);
  disp(sprintf('%8.8f', y));
 end
